@@ -4,7 +4,7 @@ use Moo;
 use MIME::Base64;
 with 'WebService::Client';
 
-our $VERSION = '0.0002';
+our $VERSION = '0.0003';
 
 use Carp qw(croak);
 
@@ -19,8 +19,8 @@ sub BUILD {
     $self->ua->default_header(Authorization => "Basic " . $basic);
 }
 sub send {
-    my ($self,$method) = @_;
-    return $self->get($method);
+    my ($self,$method,$data) = @_;
+    return $self->get($method,$data);
 }
 sub send_post {
     my ($self,$method,$data) = @_;
@@ -32,6 +32,11 @@ sub send_put{
 	return $self->post($method,$data);
 }
 
+sub send_delete{
+    my ($self,$method,$data) = @_;
+    return $self->post($method,$data);
+}
+
 1
 
 __END__
@@ -46,11 +51,11 @@ WebService::MailJet - WebService::MailJet
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
-	use WebService::Mailjet;
+    use WebService::Mailjet;
 
     my $mailjet = WebService::MailJet->new(auth_key => 'abc',auth_secret=>'xyz');
 
